@@ -17,5 +17,5 @@ Including another URLconf
 from django.urls import path, include
 
 urlpatterns = [
-       path('bi_report/', include('apps.bi_report.urls')),
+       path('', include('apps.bi_report.urls')),
 ]
